Learn R Programming

catmaply (version 0.9.3)

discrete_coloring: Generates the parameters necessary for discrete coloring and colorbar

Description

Generates the parameters necessary for discrete coloring and colorbar

Usage

discrete_coloring(categories, col_palette, range_min, range_max)

Value

list(colorscale, tickvals, ticktext)

Arguments

categories

categories, for coloring should done

col_palette

the color palette

range_min

max of z range; (default: length(categories))